@@ -2,7 +2,7 @@ from .tournament import Tournament, TournamentProvider, TournamentCodes, Tournam
 from .championmastery import ChampionMasteries, ChampionMastery
 from .league import League, ChallengerLeague, GrandmasterLeague, MasterLeague, SummonerLeague, DivisionLeague
 from .clash import ClashPlayers, ClashTeam, ClashTournaments, ClashTournament
-from .match import Match, Timeline, MatchHistory, Matches
+from .match import Match, Timeline, MatchHistory
 from .profileicon import ProfileIcon, ProfileIcons
 from .spectator import FeaturedGames, CurrentGame
 from .championrotation import ChampionRotation
@@ -10,7 +10,7 @@ from .thirdpartycode import ThirdPartyCode
 from .merakichampion import MerakiChampion
 from .merakiitem import MerakiItem
 from .spell import Spell, Spells
-from .champion import Champion
+from .champion import Champion, Champions
 from .summoner import Summoner
 from .item import Item, Items
 from .rune import Rune, Runes
