@@ -1,6 +1,13 @@
 from datetime import datetime
-from typing import List, Iterator
-from .__core__ import PyotCore
+from typing import List, Iterator, TYPE_CHECKING
+
+from pyot.conf.model import models
+from .base import PyotCore
+
+if TYPE_CHECKING:
+    from .summoner import Summoner
+    from .champion import Champion
+    from .merakichampion import MerakiChampion
 
 
 # PYOT CORE OBJECTS
@@ -10,7 +17,6 @@ class ChampionMastery(PyotCore):
     champion_level: int
     champion_points: int
     last_play_timestamp: int
-    last_play_time: datetime
     champion_points_since_last_level: int
     champion_points_until_next_level: int
     chest_granted: bool
@@ -21,8 +27,8 @@ class ChampionMastery(PyotCore):
         rules = {"champion_mastery_v4_by_champion_id": ["summoner_id", "champion_id"]}
         renamed = {'last_play_time': 'last_play_timestamp'}
 
-    def __init__(self, summoner_id: str = None, champion_id: int = None, platform: str = None):
-        self._lazy_set(locals())
+    def __init__(self, summoner_id: str = None, champion_id: int = None, platform: str = models.lol.DEFAULT_PLATFORM):
+        self.initialize(locals())
 
     @property
     def last_play_time(self) -> datetime:
@@ -36,7 +42,7 @@ class ChampionMastery(PyotCore):
     @property
     def champion(self) -> "Champion":
         from .champion import Champion
-        return Champion(id=self.champion_id, locale=self.to_locale(self.platform))
+        return Champion(id=self.champion_id)
 
     @property
     def meraki_champion(self) -> "MerakiChampion":
@@ -64,10 +70,10 @@ class ChampionMasteries(PyotCore):
     def __len__(self):
         return len(self.masteries)
 
-    def __init__(self, summoner_id: str = None, platform: str = None):
-        self._lazy_set(locals())
+    def __init__(self, summoner_id: str = None, platform: str = models.lol.DEFAULT_PLATFORM):
+        self.initialize(locals())
 
-    def _transform(self, data):
+    def transform(self, data):
         new_data = {}
         new_data["totalScore"] = 0
         for a in data:
