@@ -1,9 +1,11 @@
-from datetime import datetime, timedelta
-from ..functools import async_property
-
 import asyncio
+from datetime import datetime, timedelta
+from functools import cached_property
+
 import aiohttp
 
+from ..functools import async_property
+
 
 class ChampionKeysCache:
 
@@ -16,12 +18,15 @@ class ChampionKeysCache:
             "name_by_id": {},
             "name_by_key": {},
         }
-        self.lock = asyncio.Lock()
         self.last_updated = datetime.now() - timedelta(days=1)
 
     def __str__(self) -> str:
         return 'ChampionKeysCache()'
 
+    @cached_property
+    def lock(self):
+        return asyncio.Lock()
+
     @async_property
     async def data(self):
         if datetime.now() - self.last_updated < timedelta(hours=3):
